==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/datagen/EquipmentAssetProvider.java <==
package cc.thonly.reverie_dreams.datagen;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.armor.*;
import cc.thonly.reverie_dreams.datagen.generator.AbstractEquipmentAssetProvider;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.minecraft.class_10186;
import net.minecraft.class_10394;
import net.minecraft.class_5321;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;
import java.util.function.BiConsumer;

public class EquipmentAssetProvider extends AbstractEquipmentAssetProvider {

    public EquipmentAssetProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> future) {
        super(output, future);
    }

    @Override
    protected void bootstrap(BiConsumer<class_5321<class_10394>, class_10186> consumer) {
        consumer.accept(EarphoneArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("earphone")));
        consumer.accept(KoishiHatArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("koishi_hat")));
        consumer.accept(SilverArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("silver")));
        consumer.accept(MagicIceArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("magic_ice")));
        consumer.accept(MaidArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("maid")));
        consumer.accept(DreamArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("dream")));
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/datagen/EquipmentAssetProvider.java <==
package cc.thonly.reverie_dreams.datagen;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.armor.*;
import cc.thonly.reverie_dreams.datagen.generator.AbstractEquipmentAssetProvider;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.minecraft.class_10186;
import net.minecraft.class_10394;
import net.minecraft.class_5321;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;
import java.util.function.BiConsumer;

public class EquipmentAssetProvider extends AbstractEquipmentAssetProvider {

    public EquipmentAssetProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> future) {
        super(output, future);
    }

    @Override
    protected void bootstrap(BiConsumer<class_5321<class_10394>, class_10186> consumer) {
        consumer.accept(EarphoneArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("earphone")));
        consumer.accept(KoishiHatArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("koishi_hat")));
        consumer.accept(SilverArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("silver")));
        consumer.accept(MagicIceArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("magic_ice")));
        consumer.accept(MaidArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("maid")));
        consumer.accept(DreamArmorMaterial.REGISTRY_KEY, createHumanoidAndHorseModel(ReverieDreams.id("dream")));
        consumer.accept(WaterproofArmorMaterial.REGISTRY_KEY, class_10186.method_63994().method_63999(ReverieDreams.id("waterproof"), true).method_63999(ReverieDreams.id("waterproof_overlay"), false).method_64001(class_10186.class_10190.field_54129, class_10186.class_10189.method_64005(ReverieDreams.id("waterproof"), true)).method_63997());
    }
}
